@@ -7,6 +7,8 @@ import (
 	"os"
 	"os/exec"
 	"strings"
+	"sync"
+	"time"
 
 	"golang.org/x/crypto/ssh/terminal"
 
@@ -14,7 +16,8 @@ import (
 )
 
 const (
-	exitCode = 9
+	exitCode       = 9
+	maxPasswordLen = 1000
 )
 
 // Once tries to get a password from the user, either from the terminal, extpass
@@ -66,8 +69,8 @@ func readPasswordTerminal(prompt string) string {
 	return string(p)
 }
 
-// readPasswordStdin reads a line from stdin
-// Exits on read error or empty result.
+// readPasswordStdin reads a line from stdin.
+// It exits with a fatal error on read error or empty result.
 func readPasswordStdin() string {
 	tlog.Info.Println("Reading password from stdin")
 	p := readLineUnbuffered(os.Stdin)
@@ -83,7 +86,16 @@ func readPasswordStdin() string {
 // Exits on read error or empty result.
 func readPasswordExtpass(extpass string) string {
 	tlog.Info.Println("Reading password from extpass program")
-	parts := strings.Split(extpass, " ")
+	var parts []string
+	// The option "-passfile=FILE" gets transformed to
+	// "-extpass="/bin/cat -- FILE". We don't want to split FILE on spaces,
+	// so let's handle it manually.
+	passfileCat := "/bin/cat -- "
+	if strings.HasPrefix(extpass, passfileCat) {
+		parts = []string{"/bin/cat", "--", extpass[len(passfileCat):]}
+	} else {
+		parts = strings.Split(extpass, " ")
+	}
 	cmd := exec.Command(parts[0], parts[1:]...)
 	cmd.Stderr = os.Stderr
 	pipe, err := cmd.StdoutPipe()
@@ -115,6 +127,10 @@ func readPasswordExtpass(extpass string) string {
 func readLineUnbuffered(r io.Reader) (l string) {
 	b := make([]byte, 1)
 	for {
+		if len(l) > maxPasswordLen {
+			tlog.Fatal.Printf("fatal: maximum password length of %d bytes exceeded", maxPasswordLen)
+			os.Exit(exitCode)
+		}
 		n, err := r.Read(b)
 		if err == io.EOF {
 			return l
@@ -132,3 +148,33 @@ func readLineUnbuffered(r io.Reader) (l string) {
 		l = l + string(b)
 	}
 }
+
+// CheckTrailingGarbage tries to read one byte from stdin and exits with a
+// fatal error if the read returns any data.
+// This is meant to be called after reading the password, when there is no more
+// data expected. This helps to catch problems with third-party tools that
+// interface with gocryptfs.
+//
+// This is tested via TestInitTrailingGarbage() in tests/cli/cli_test.go.
+func CheckTrailingGarbage() {
+	if terminal.IsTerminal(int(os.Stdin.Fd())) {
+		// Be lenient when interacting with a human.
+		return
+	}
+	var wg sync.WaitGroup
+	wg.Add(1)
+	go func() {
+		b := make([]byte, 1)
+		wg.Done()
+		n, _ := os.Stdin.Read(b)
+		if n > 0 {
+			tlog.Fatal.Printf("Received trailing garbage after the password")
+			os.Exit(exitCode)
+		}
+	}()
+	// Wait for the goroutine to start up plus one millisecond for the read to
+	// return. If there is data available, this SHOULD be plenty of time to
+	// read one byte. However, I don't see a way to be sure.
+	wg.Wait()
+	time.Sleep(1 * time.Millisecond)
+}
